@@ -1,3 +1,4 @@
+import os
 import ssl
 import xml.etree.ElementTree as et
 
@@ -17,6 +18,7 @@ ns = {
 }
 
 login_endpoint = 'login/Services/PartnerSystemUserService.svc'
+wsdl_path = os.path.join(os.path.dirname(os.path.realpath(__file__)), 'partner.wsdl')
 
 
 def SuperOfficeLogin(cust_id, app_token, sys_token,
@@ -37,7 +39,7 @@ def SuperOfficeLogin(cust_id, app_token, sys_token,
             ('ContextIdentifier', cust_id)
         ])
 
-        client = Client('file:%s' % 'partner.wsdl')
+        client = Client('file:%s' % wsdl_path)
         client.set_options(soapheaders=headers)
         client.set_options(location='https://{env}.superoffice.com/{endpoint}'.format(
             env=environment, endpoint=login_endpoint))
